@@ -1,8 +1,8 @@
-
+dates <- as.Date(c("2022-09-05", "2022-09-06"))
 test_that("hourly works", {
     skip_if_offline()
     skip_on_cran()
-    dates <- seq.Date(lubridate::today() - 3, lubridate::today() - 2, by = "1 day")
+
     results <- GetSMNData(dates, type = "hourly")
 
     expect_true(inherits(results, "data.frame"))
@@ -15,7 +15,7 @@ test_that("hourly works", {
 test_that("daily works", {
     skip_if_offline()
     skip_on_cran()
-    dates <- seq.Date(lubridate::today() - 15, lubridate::today() - 2, by = "1 day")
+
     results <- GetSMNData(dates, type = "daily")
 
     expect_true(inherits(results, "data.frame"))
@@ -29,8 +29,8 @@ test_that("daily works", {
 test_that("radiation works", {
     skip_if_offline()
     skip_on_cran()
-    # skip("radiation data doesn't seem to be available.")
-    dates <- seq.Date(lubridate::today() - 50, lubridate::today() - 45, by = "1 day")
+
+
     results <- GetSMNData(dates, type = "radiation")
 
     expect_true(inherits(results, "data.frame"))
